pub struct SoftPre {
pub tabs_to_nbsp: Option<u8>,
pub autolink: bool,
pub input_line_separator: &'static str,
pub trailing_br: bool,
}Expand description
Create plain text to HTML that mimicks <pre>, but still allows
dynamic line breaks
Fields
tabs_to_nbsp: Option<u8>Whether to replace tabs with the given number of non-breaking spaces.
autolink: boolWhether to turn http:// and https:// URLs into links.
input_line_separator: &'static strThe input text is split on this string into lines
trailing_br: boolWhether to add a trailing <br>
Implementations